<?php
// Menüye Ekleme
add_action('admin_menu', 'klm_add_admin_menu');
function klm_add_admin_menu() {
    add_menu_page('İç Link Yöneticisi', 'İç Link Yöneticisi', 'manage_options', 'klm', 'klm_dashboard_page', 'dashicons-admin-links', 20);
}

// Dashboard Sayfası İçeriği
function klm_dashboard_page() {
    global $wpdb;
    $table_name = $wpdb->prefix . "klm_keywords";

    // Yeni kelime ekleme formunu işle
    if (isset($_POST['submit'])) {
        $keyword = sanitize_text_field($_POST['keyword']);
        $url = esc_url($_POST['url']);
        
        // Veritabanına yeni kelimeyi ekle
        $wpdb->insert(
            $table_name,
            array(
                'keyword' => $keyword,
                'url' => $url
            ),
            array(
                '%s',
                '%s'
            )
        );

        // Başarı mesajı göster
        echo '<div id="message" class="updated notice is-dismissible"><p>Kelime başarıyla eklendi!</p><button type="button" class="notice-dismiss"><span class="screen-reader-text">Bu bildirimi kapat</span></button></div>';
    }

    // Anahtar kelimeleri çek
    $keywords = $wpdb->get_results("SELECT * FROM $table_name");

    // Anahtar kelime silme işlemi
    if (isset($_GET['delete'])) {
        $id = intval($_GET['delete']);
        $wpdb->delete($table_name, array('id' => $id));
        klm_update_all_posts(); // Tüm postları güncelle
        // Başarı mesajı göster
        echo '<div id="message" class="updated notice is-dismissible"><p>Kelime başarıyla silindi!</p><button type="button" class="notice-dismiss"><span class="screen-reader-text">Bu bildirimi kapat</span></button></div>';
    }
    ?>
    <div class="wrap">
        <h1>İç Link Yöneticisi</h1>
        <form method="post" action="">
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Anahtar/Kategori Kelimeniz</th>
                    <td><input type="text" name="keyword" required /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Linklenecek URL</th>
                    <td><input type="url" name="url" required /></td>
                </tr>
            </table>
            <p class="submit">
                <input type="submit" name="submit" class="button-primary" value="Kaydet" />
            </p>
        </form>
        
            Eklediğiniz anahtar kelimeler bir 3,4 saniye bekleme süresi yapabilir, bu sitenizdeki anahtar kelime yoğunluğuna göre değişliklik gösterebilir. Sorgu beklemek istemezseniz eğer, soldaki menülerde başka menülere tıklayarak<br> hızlanmasını sağlayabilirsiniz

        <h2>Mevcut Anahtar Kelimeler Raporu</h2>
        <table class="widefat">
            <thead>
                <tr>
                    <th>Anahtar Kelime</th>
                    <th>Yönlenen URL</th>
                    <th>Kullanım Sayısı</th>
                    <th>İşlemler</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($keywords as $keyword) : ?>
                    <tr>
                        <td><?php echo $keyword->keyword; ?></td>
                        <td><a href="<?php echo $keyword->url; ?>" target="_blank"><?php echo $keyword->url; ?></a></td>
                        <td><?php echo klm_count_keyword_usage_custom($keyword->keyword); ?></td>
                        <td><a href="?page=klm&delete=<?php echo $keyword->id; ?>" onclick="return confirm('Bu kelimeyi silmek istediğinizden emin misiniz?')">Sil</a></td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
    
    <?php
}

// Anahtar Kelimenin Kullanım Sayısını Bulma Fonksiyonu
function klm_count_keyword_usage_custom($keyword) {
    global $wpdb;
    $count = 0;
    $args = array('post_type' => 'post', 'posts_per_page' => -1);
    $query = new WP_Query($args);
    while ($query->have_posts()) {
        $query->the_post();
        $content = get_the_content();
        $count += substr_count(strtolower(strip_tags($content)), strtolower($keyword));
    }
    wp_reset_postdata();
    return $count;
}

// // dashboard.php

// Tüm Postları Güncelleme Fonksiyonu
function klm_update_all_posts() {
    global $wpdb;
    $args = array('post_type' => 'post', 'posts_per_page' => -1);
    $query = new WP_Query($args);
    while ($query->have_posts()) {
        $query->the_post();
        $post_id = get_the_ID();
        $content = get_the_content();
        // Post içeriğini güncelle
        $updated_content = klm_add_keyword_links_v2($content); // Fonksiyonun adını değiştirdik
        wp_update_post(array(
            'ID' => $post_id,
            'post_content' => $updated_content 
        ));
    }
    wp_reset_postdata();
}


// keyword-link-manager.php

// Anahtar Kelimelere Link Ekleme Fonksiyonu
function klm_add_keyword_links_v2($content) {
    global $wpdb;
    $table_name = $wpdb->prefix . "klm_keywords";
    $keywords = $wpdb->get_results("SELECT * FROM $table_name");
    
    // Paragrafları ayır
    $paragraphs = explode("</p>", $content);
    
    foreach ($paragraphs as $paragraph) {
        // Paragraftaki kelimeleri bul
        foreach ($keywords as $keyword) {
            if (stripos($paragraph, $keyword->keyword) !== false) {
                // Kelimeyi link haline getir
                $link = '<a href="' . $keyword->url . '" target="_blank">' . $keyword->keyword . '</a>';
                // Paragraftaki kelimeyi linke dönüştür
                $paragraph = str_ireplace($keyword->keyword, $link, $paragraph);
            }
        }
    }

    // Düzenlenmiş paragrafları birleştir
    $updated_content = implode("</p>", $paragraphs);

    return $updated_content;
}



// Özel Script Ekleme Fonksiyonu
function klm_enqueue_custom_script() {
    wp_enqueue_script( 'klm-custom-script', get_template_directory_uri() . '/custom-script.js', array('jquery'), '1.0', true );
}
add_action( 'admin_enqueue_scripts', 'klm_enqueue_custom_script' );
?>
